/*
	main.c
 
    This file is part of munpak.
 
    A post-processing tool for parsing Mobitex data packets (MPAKs)

    Copyright (c) 2002 @stake, Inc.
*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "munpak.h"

char copyright[] = "Copyright (c) 2002, @stake, Inc. [kingpin@atstake.com]";

int main (int argc, char *argv[])
{
	int c;
    unsigned long man = 0;
    unsigned char filename[FILENAME_MAX];
    FILE *fp;

	if (argc > 1)
	{
		/* if no options specified */
		if (_stricmp (argv[1], "-h") != 0 && 
			_stricmp (argv[1], "-m") != 0)
				strncpy (filename, argv[1], FILENAME_MAX-1);

		/* check options */
		for (c = 1; c < argc; c++)
		{
			if (_stricmp (argv[c], "-h") == 0) /* help */
				help(); 
			
            if (_stricmp (argv[c], "-m") == 0) /* mobile access number */
			{
                if (argv[c+1]) man = atol(argv[c+1]); 
				if (man == 0) usage(argv[0]); // returns 0 if invalid

                if (argv[c+2]) strncpy (filename, argv[c+2], FILENAME_MAX-1);
                else usage(argv[0]); // no filename specified
			}
		}
	}
    else
        usage(argv[0]);

    if ((fp = fopen(filename, "rt")) == NULL) // open log file for reading
	{
		fprintf(stderr, "\nUnable to open %s\n", filename);			
		usage(argv[0]);
	}

    parse (man, fp); /* finally invoke the real routine */

	return 0;
}


void usage (char *argv)
{
	fprintf(stderr, "\nUse '%s -h' for help\n", argv);
	exit(0);
}


void help (void)
{
	fprintf(stdout, "\n@stake [kingpin@atstake.com], January 2002 v1.00");

	fprintf(stdout, "\n\nNAME");
	fprintf(stdout, "\n\tmunpak - A post-processing tool for parsing Mobitex data");
	fprintf(stdout, "\n\tpackets (MPAKs)");
	
	fprintf(stdout, "\n\nUSAGE");
	fprintf(stdout, "\n\tmunpak [ options... ] <raw mobitex filename>");

	fprintf(stdout, "\n\nOPTIONS");
	fprintf(stdout, "\n\t-h             : you're reading it");
	fprintf(stdout, "\n\t-m man         : specific man to parse [default: parses all]");

    fprintf(stdout, "\n\n");
	exit(0);
}
