/*
	munpak.h
 
    This file is part of munpak.
 
    Copyright (c) 2002 @stake, Inc.
*/

/*-------------------------------------------------------------------------*
 * To Do List.
 *-------------------------------------------------------------------------*

    1. Recreate packets in correct sequence order, handle extra space at end
    2. Crashes on large input files
    3. Address List support
    4. HPID support for HPDATA type (1 byte after timestamp before data)

 *-------------------------------------------------------------------------*/

#ifndef __INC_PDD_H
#define __INC_PDD_H

#pragma pack(push,1) // align to 1-byte boundaries


/*-------------------------------------------------------------------------*
 * Globals.
 *-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*
 * Types.
 *-------------------------------------------------------------------------*/

typedef unsigned char byte;

typedef struct {
    byte   man[3];       // Mobitex Access Number (MAN)
    byte   frame;        // Frame ID
    byte   sequence;     // Sequence Number
    byte   blocks;       // # of Data Blocks (20 byte structure)
} ROSI; // Radio Oriented Synchronous Information

typedef struct {
    byte   sender[3];    // Sender MAN number
    byte   dest[3];      // Addressee MAN number
    byte   flags;        // MPAK flags (and traffic state)
    byte   type;         // PSUBCOM MPAK type, 0 for non-PSUBCOM
    byte   time[3];      // Mobitex raw time stamp (Minutes since 1/1/1985, 12am, Mobitex Local Time) Set to 0 when TX
    byte   packet;       // Packet ID (used to identify data blocks from multiple MPAKs)
} HEADER; // Specific to Blackberry protocol (subset of MPAK_HEADER)

typedef struct {
    ROSI   Rosi;
    HEADER Header;
    byte   Data[522];    // Maximum user data per MPAK (29 lines * 18 bytes)
} MPAK;

typedef struct __donelist {
	byte man[3];
    byte sequence;
    byte packet;
	struct __donelist *next;
} DONELIST;

typedef enum
{
    MIME, // E-mail
    ICAL, // iCalendar
    RAW   // Unknown
} MTYPE;

/*typedef struct {
    byte unknown1[9];
    byte source_length;             // RX only
    byte source[source_length+1];   // RX only
    byte dest_length;
    byte dest[dest_length+1];
    byte unknown2[5];
    byte type_length;
    byte type[type_length];
    byte unknown3[5];               
    byte mail_type_flag;            // $54 cleartext, original
                                    // $5C cleartext, forwarded
                                    // $64, 6C cleartext, new text + forwarded
} CMIME_HEADER;  // Message Type: E-Mail

typedef struct {
    byte unknown4[10];
    byte to_length;
    byte to[to_length+1];
    byte from_length;
    byte from[from_length];
    byte unknown5[7];
    byte subject_length;
    byte subject[subject_length];
    byte unknown6[15];
    byte body_length;
    byte body[body_length+1];
} CMIME_CLEARTEXT;

typedef struct {
    byte unknown4[10];
    byte to_length;
    byte to[to_length+1];
    byte from_length;
    byte from[from_length];
    byte unknown5[7];
    byte subject_length;
    byte subject[subject_length];
    byte unknown6[30];
    byte body_length;
    byte body[body_length+1];
} CMIME_FORWARDED;

typedef struct {
    byte unknown4[5];
    byte to_length = 0;
    byte data[???];
} CMIME_ENCRYPTED;

*/


/*-------------------------------------------------------------------------*
 * Function Definitions.
 *-------------------------------------------------------------------------*/

// main.c
void	usage (char *argv);
void	help  (void);

// parse.c
void    parse (unsigned long man, FILE* fp);
void    display (MPAK *mpak, int packet);

// util.c
void    hexdisplay (unsigned char *data, unsigned long length);
char    *strmem (const char *string, const char *strCharSet, int memlen);
int     atoc (const char *instr, char *out);
void    freelist (DONELIST *pl);

/*-------------------------------------------------------------------------*
 * Constants.
 *-------------------------------------------------------------------------*/

#pragma pack(pop)

#endif  /* __INC_PDD_H */


